import Qt 4.7

Rectangle {
    id: root
    anchors.fill: parent

    SystemPalette { id: myPalette; colorGroup: SystemPalette.Active }
    color: myPalette.window

    property int margin: Math.max(2, root.height / 100 )
    property int spacing: root.margin * 3
    property int buttonSize: (root.height - 10 * root.spacing - 2 * root.margin) / 6

    // top-left button group: next subtitle, next language, back
    RemoteButton {
        id: nextSubtitleButton
        iconSource: "../images/btn_next_subtitle.png"

        anchors {left: root.left; top: root.top; topMargin: root.margin}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionNextSubtitle()
    }

    RemoteButton {
        id: nextLanguageButton
        iconSource: "../images/btn_next_language.png"

        anchors {left: nextSubtitleButton.left; top: nextSubtitleButton.bottom; topMargin: root.spacing}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionNextLanguage()
    }

    RemoteButton {
        id: backButton
        iconSource: "../images/btn_back.png"

        anchors {left: nextLanguageButton.left; top: nextLanguageButton.bottom; topMargin: root.spacing}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionBack()
    }

    // top-middle button group: gui, context menu, escape
    RemoteButton {
        id: guiButton
        iconSource: "../images/btn_gui.png"

        anchors {horizontalCenter: root.horizontalCenter; top: root.top; topMargin: root.margin}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionShowGui()
    }

    RemoteButton {
        id: contextMenuButton
        iconSource: "../images/btn_context_menu.png"

        anchors {horizontalCenter: guiButton.horizontalCenter; top: guiButton.bottom; topMargin: root.spacing}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionContextMenu()
    }

    RemoteButton {
        id: escapeButton
        iconSource: "../images/btn_esc.png"

        anchors {horizontalCenter: contextMenuButton.horizontalCenter; top: contextMenuButton.bottom; topMargin: root.spacing}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionSendKeyEsc()
    }

    // top-right button group: volume up, volume down, mute volum
    RemoteButton {
        id: volumneUpButton
        iconSource: "../images/btn_volume_up.png"

        anchors {right: root.right; top: root.top; topMargin: root.margin}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionVolumeUp()
    }

    RemoteButton {
        id: volumeDownButton
        iconSource: "../images/btn_volume_down.png"

        anchors {right: volumneUpButton.right; top: volumneUpButton.bottom; topMargin: root.spacing}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionVolumeDown()
    }

    RemoteButton {
        id: muteVolumeButton
        iconSource: "../images/btn_mute.png"

        anchors {right: volumeDownButton.right; top: volumeDownButton.bottom; topMargin: root.spacing}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionMute()
    }

    // bottom button group: stop, enter/select
    RemoteButton {
        id: stopButton
        iconSource: "../images/btn_stop.png"

        anchors {left: root.left; bottom: root.bottom; bottomMargin: root.margin}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionStop()
    }

    RemoteButton {
        id: enterButton
        iconSource: "../images/btn_enter.png"

        anchors {right: root.right; bottom: root.bottom; bottomMargin: root.margin}
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionSelect()
    }


    // central navigation area: left, up, play/payse, down, right
    RemoteButton {
        id: playPauseButton
        iconSource: "../images/btn_play_pause.png"

        x: (root.width - root.buttonSize) / 2
        y: root.margin + 6 * root.spacing + 4 * root.buttonSize
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionPlay()
    }

    RemoteButton {
        id: leftButton
        iconSource: "../images/btn_left.png"

        x: playPauseButton.x - root.buttonSize - root.spacing
        y: playPauseButton.y
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionLeft()
    }

    RemoteButton {
        id: upButton
        iconSource: "../images/btn_up.png"

        x: playPauseButton.x
        y: playPauseButton.y - root.buttonSize - root.spacing
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionUp()
    }

    RemoteButton {
        id: downButton
        iconSource: "../images/btn_down.png"

        x: playPauseButton.x
        y: playPauseButton.y + root.buttonSize + root.spacing
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionDown()
    }

    RemoteButton {
        id: rightButton
        iconSource: "../images/btn_right.png"

        x: playPauseButton.x + root.buttonSize + root.spacing
        y: playPauseButton.y
        width: root.buttonSize
        height: root.buttonSize
        onClicked: xbmc.actionRight()
    }
}
